##  Editing in Landscape Report
Within the report, users are able to quickly modify tags, attributes, and relations to fact sheets using the Edit pane. In order to access the Edit pane in a landscape report, click on the application fact sheet that requires modification. The right side pane displays information about the fact sheet and provides for editing its properties. Any adjustments made are immediately implemented within both the report and the fact sheet itself.
**Note**
  * Only the fact sheet data that is actually displayed on the report is editable in the pane. A different view or setting (e.g., left and right property) can be applied to modify the report without modifying fact sheet's data.
  * Since the data represents the current state, editing is only available at the 'Today' date on the timeline, not for the report's past or future states.

![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2748ec657a441014a8bf8ec8e842c605_LowRes.png)
